@@ -717,7 +717,7 @@ end
 Density matrix type, where `state` is a matrix.
 Type parameter `D` is the number of levels, it can also be specified by a keyword argument `nlevel`.
 """
-struct DensityMatrix{D,T,MT<:AbstractMatrix{T}} <: AbstractRegister{D}
+mutable struct DensityMatrix{D,T,MT<:AbstractMatrix{T}} <: AbstractRegister{D}
     state::MT
 end
 
